<template>
    <div class="system-role-container">
        <el-card shadow="hover">
            <div class="system-user-search mb15">
                <div class="basic-line">
                    <span>排查结果：</span>
                    <el-select class="input-box" v-model="recordData.params.result" placeholder="排查结果" filterable clearable>
                        <el-option v-for="item in resultList" :key="item.id" :label="item.name" :value="item.id"></el-option>
                    </el-select>
                </div>
                <div class="basic-line">
                    <span>排查任务状态：</span>
                    <el-select class="input-box" v-model="recordData.params.taskStatus" placeholder="排查任务状态" filterable clearable>
                        <el-option v-for="item in taskStatusList" :key="item.id" :label="item.name" :value="item.id"></el-option>
                    </el-select>
                </div>
                <div class="basic-line">
                    <span>任务类型：</span>
                    <el-select class="input-box" v-model="recordData.params.taskType" placeholder="任务类型" filterable clearable>
                        <el-option v-for="item in taskTypeList" :key="item.id" :label="item.name" :value="item.id"></el-option>
                    </el-select>
                </div>

                <el-button size="default" type="primary" class="ml10" v-throttle @click="handleSearch">
                    <el-icon>
                        <ele-Search />
                    </el-icon>
                    查询
                </el-button>
            </div>
            <el-table :data="recordData.data" style="width: 100%">
                <el-table-column type="expand">
                    <template #default="scope">
                        <el-table :data="scope.row.checkContent" style="width: 100%">
                            <el-table-column label="序号" type="index" width="150" align="center"> </el-table-column>
                            <el-table-column label="检查内容" prop="checkContent" align="center"> </el-table-column>
                            <el-table-column label="检查结果" prop="checkResult" align="center">
                                <template #default="scope">
                                    <el-tag :type="scope.row.checkResult === 1 ? 'success' : scope.row.checkResult === 2 ? 'danger' : 'info'">
                                        {{ parseNumber(scope.row.checkResult, '检查结果') }}
                                    </el-tag>
                                </template>
                            </el-table-column>
                            <el-table-column label="操作" align="center" width="280" class-name="small-padding fixed-width">
                                <template #default="scope">
                                    <el-button size="small" text type="primary" :icon="View" @click="onOpenDialogRef('查看', scope.row)">查看</el-button>
                                    <el-button size="small" text type="primary" :icon="Check" @click="onOpenDialogRef('整改', scope.row)">提交</el-button>
                                </template>
                            </el-table-column>
                        </el-table>
                    </template>
                </el-table-column>
                <el-table-column type="index" label="序号" width="60" />
                <el-table-column prop="taskCode" label="排查名称" show-overflow-tooltip></el-table-column>
                <el-table-column prop="execDepId" label="执行部门" show-overflow-tooltip>
                    <template #default="scope">
                        {{ parseNumber(scope.row.execDepId, '执行部门') }}
                    </template>
                </el-table-column>
                <el-table-column prop="taskStatus" label="状态" show-overflow-tooltip>
                    <template #default="scope">
                        {{ parseNumber(scope.row.taskStatus, '状态') }}
                    </template>
                </el-table-column>
                <el-table-column prop="taskBelong" label="是否认领" show-overflow-tooltip>
                    <template #default="scope">
                        {{ parseNumber(scope.row.taskBelong, '认领状态') }}
                    </template>
                </el-table-column>
                <el-table-column prop="createUserName" label="创建人" show-overflow-tooltip></el-table-column>
                <el-table-column prop="gmtCreate" label="创建时间" show-overflow-tooltip></el-table-column>
                <el-table-column prop="lastEditUserName" label="最后修改人" show-overflow-tooltip></el-table-column>
                <el-table-column prop="gmtModitify" label="最后修改时间" show-overflow-tooltip></el-table-column>
                <el-table-column label="操作" align="center" width="280" class-name="small-padding fixed-width">
                    <template #default="scope">
                        <el-button size="small" text type="primary" v-show="(scope.row.taskStatus === 1 || scope.row.taskStatus === 4) && scope.row.taskBelong === 1" :icon="Check" @click="onHandleTask(scope.row)">任务认领</el-button>
                    </template>
                </el-table-column>
            </el-table>
            <br />
            <el-pagination @size-change="onHandleSizeChange" @current-change="onHandleCurrentChange" :pager-count="5" :page-sizes="[10, 20, 30]" v-model:current-page="recordData.params.pageIndex" background v-model:page-size="recordData.params.pageSize" layout="total, sizes, prev, pager, next, jumper" :total="recordData.total" class="page-position"> </el-pagination>
            <br />
            <br />
        </el-card>
        <recordDialog ref="recordDialogRef" @refreshrecord="initRecordTableData" />
    </div>
</template>

<script lang="ts">
import { toRefs, reactive, onMounted, ref, defineComponent } from 'vue';
import { ElMessageBox, ElMessage } from 'element-plus';
import recordDialog from './components/recordDialog.vue';
import { recordApi } from '/@/api/doublePreventSystem/record/index.ts';
import { departmentApi } from '/@/api/systemManage/department';
import { checkUnitApi } from '/@/api/doublePreventSystem/checkUnit';
import { View, Check } from '@element-plus/icons-vue';

// 定义接口来定义对象的类型
interface TableData {
    roleName: string;
    roleSign: string;
    describe: string;
    sort: number;
    status: boolean;
    createTime: string;
}
interface TableDataState {
    recordData: {
        data: Array<TableData>;
        total: number;
        loading: boolean;
        params: {
            pageIndex: number;
            pageSize: number;
            result: number | null;
            taskStatus: number | null;
            taskType: number | null;
        };
    };
    taskUnitList: [];
    departmentList: Array<DepartmentState>;
    departmentRecursionList: Array<DepartmentState>;
    resultList: Array<levelListState>;
    checkResultList: Array<levelListState>;
    taskStatusList: Array<levelListState>;
    taskTypeList: Array<levelListState>;
}
interface levelListState {
    id: number;
    name: string;
}
interface DepartmentState {
    depId: number;
    depName: string;
}

export default defineComponent({
    name: 'record',
    components: { recordDialog, View, Check },
    setup() {
        const recordDialogRef = ref();
        const state = reactive<TableDataState>({
            recordData: {
                data: [],
                total: 0,
                loading: false,
                params: {
                    pageIndex: 1,
                    pageSize: 10,
                    result: null,
                    taskStatus: null,
                    taskType: null
                }
            },
            taskUnitList: [],
            departmentList: [],
            departmentRecursionList: [],
            resultList: [
                { id: 1, name: '正常' },
                { id: 2, name: '存在隐患' },
                { id: 3, name: '未排查' },
                { id: 4, name: '其他' }
            ],
            checkResultList: [
                { id: 1, name: '正常' },
                { id: 2, name: '异常' },
                { id: 3, name: '未处理' }
            ],
            taskStatusList: [
                { id: 1, name: '待排查' },
                { id: 2, name: '已完成' },
                { id: 3, name: '超时未排查' },
                { id: 4, name: '排查中' }
            ],
            taskTypeList: [
                { id: 1, name: '周期任务' },
                { id: 2, name: '日常任务' }
            ]
        });
        // 初始化表格数据
        const initRecordTableData = async () => {
            let res = await recordApi().getRecordList(state.recordData.params);
            if (res.data.code === '200') {
                state.recordData.data = res.data.data;
                state.recordData.total = res.data.count;
            } else {
                ElMessage({
                    type: 'warning',
                    message: res.data.msg
                });
            }
        };

        //获取部门列表
        const getDepartmentData = async () => {
            let res = await departmentApi().getDepartmentList();
            if (res.data.code === '200') {
                state.departmentList = res.data.data;
                recursion(state.departmentList);
            } else {
                ElMessage({
                    type: 'warning',
                    message: res.data.msg
                });
            }
        };

        const getCheckUnitData = async () => {
            let res = await checkUnitApi().getAllCheckUnitList();
            if (res.data.code === '200') {
                state.taskUnitList = res.data.data;
            } else {
                ElMessage({
                    type: 'warning',
                    message: res.data.msg
                });
            }
        };

        // 打开生产装置弹窗
        const onOpenDialogRef = (type: string, value: any) => {
            recordDialogRef.value.openRecordDialog(type, value);
        };
        // 删除角色
        const onHandleTask = (row: any) => {
            ElMessageBox.confirm(`此操作将认领该任务：“${row.taskCode}”，是否继续?`, '提示', {
                confirmButtonText: '确认',
                cancelButtonText: '取消',
                type: 'warning'
            })
                .then(async () => {
                    let res = await recordApi().getTask({ id: row.id });
                    if (res.data.code === '200') {
                        ElMessage({
                            type: 'success',
                            duration: 2000,
                            message: '认领成功'
                        });
                        await initRecordTableData();
                    } else {
                        ElMessage({
                            type: 'warning',
                            message: res.data.msg
                        });
                    }
                })
                .catch(() => {});
        };

        const handleSearch = () => {
            initRecordTableData();
        };
        // 分页改变
        const onHandleSizeChange = (val: number) => {
            state.recordData.params.pageSize = val;
            initRecordTableData();
        };
        // 分页改变
        const onHandleCurrentChange = (val: number) => {
            state.recordData.params.pageIndex = val;
            initRecordTableData();
        };

        const recursion = (value: any) => {
            for (let i of value) {
                if (i.children.length !== 0) {
                    state.departmentRecursionList.push(i);
                    recursion(i.children);
                } else {
                    state.departmentRecursionList.push(i);
                }
            }
        };

        const parseNumber = (value: string | number, type: string) => {
            if (type === '状态') {
                return state.taskStatusList.find((item) => item.id === value)?.name;
            } else if (type === '执行部门') {
                return state.departmentRecursionList.find((item) => item.depId === value)?.depName;
            } else if (type === '检查结果') {
                return state.checkResultList.find((item) => item.id === value)?.name;
            } else {
                if (value === 1) {
                    return '未认领';
                } else {
                    return '已认领';
                }
            }
        };

        // 页面加载时
        onMounted(() => {
            initRecordTableData();
            getCheckUnitData();
            getDepartmentData();
        });

        return {
            View,
            Check,
            parseNumber,
            handleSearch,
            onOpenDialogRef,
            onHandleSizeChange,
            onHandleTask,
            onHandleCurrentChange,
            recordDialog,
            recordDialogRef,
            initRecordTableData,
            ...toRefs(state)
        };
    }
});
</script>

<style scoped></style>
